@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2017-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <tao/pegtl.hpp>
@@ -18,7 +18,7 @@ struct bar
 {
 };
 
-int main( int /*unused*/, char** /*unused*/ )
+int main()  // NOLINT
 {
    if( analyze< foo >() != 0 ) {
       std::cout << "there are problems" << std::endl;
