@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <cstring>
@@ -86,7 +86,7 @@ namespace dynamic
 
 }  // namespace dynamic
 
-int main( int argc, char** argv )
+int main( int argc, char** argv )  // NOLINT
 {
    if( argc > 1 ) {
       std::string id;
