@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2017-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <iomanip>
@@ -14,7 +14,7 @@
 using namespace tao::TAO_PEGTL_NAMESPACE;  // NOLINT
 using grammar = must< json::text, eof >;
 
-int main( int argc, char** argv )
+int main( int argc, char** argv )  // NOLINT
 {
    counter_state cs;
 
