@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <tao/pegtl.hpp>
@@ -35,7 +35,7 @@ namespace modulus
 
 }  // namespace modulus
 
-int main( int argc, char** argv )
+int main( int argc, char** argv )  // NOLINT
 {
    if( argc > 1 ) {
       argv_input<> in( argv, 1 );
