@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <iostream>
@@ -11,7 +11,7 @@ namespace pegtl = tao::TAO_PEGTL_NAMESPACE;
 
 using grammar = pegtl::must< pegtl::uri::URI >;
 
-int main( int argc, char** argv )
+int main( int argc, char** argv )  // NOLINT
 {
    for( int i = 1; i < argc; ++i ) {
       std::cout << "Parsing " << argv[ i ] << std::endl;
