@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2018 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include "test.hpp"
@@ -10,7 +10,7 @@ namespace tao
    {
       void unit_test()
       {
-         verify_seqs< must >( result_type::GLOBAL_FAILURE );
+         verify_seqs< must >( result_type::global_failure );
       }
 
    }  // namespace TAO_PEGTL_NAMESPACE
